@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -40,5 +40,5 @@ QString DefaultCombinedViewFormatter::formatArticles(const QVector<Article> &art
 
 QString DefaultCombinedViewFormatter::formatSummary(TreeNode *) const
 {
-    return QString();
+    return {};
 }
