@@ -16,6 +16,8 @@
 class KSqueezedTextLabel;
 class KHamburgerMenu;
 class KToggleAction;
+class KToggleFullScreenAction;
+class QTimer;
 namespace Akregator
 {
 class Part;
@@ -78,14 +80,18 @@ private Q_SLOTS:
     void optionsConfigureToolbars();
     void applyNewToolbarConfig();
     void slotOnShutdown();
+    void updateStatusbarProgressVisibility();
 
 private:
     void updateHamburgerMenu();
     void slotToggleMenubar(bool dontShowWarning);
+    void slotFullScreen(bool t);
     QPointer<Akregator::Part> m_part;
     KSqueezedTextLabel *const m_statusLabel;
+    QWidget *m_statusbarProgress = nullptr;
+    QTimer *m_hideProgressTimer = nullptr;
     KHamburgerMenu *mHamburgerMenu = nullptr;
     KToggleAction *mShowMenuBarAction = nullptr;
+    KToggleFullScreenAction *mShowFullScreenAction = nullptr;
 };
 } // namespace Akregator
-
